@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2014-2015 by Farsight Security, Inc.
+ * Copyright (c) 2012-2019 by Farsight Security, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,8 +38,11 @@ typedef enum {
 	MTBL_COMPRESSION_ZLIB = 2,
 	MTBL_COMPRESSION_LZ4 = 3,
 	MTBL_COMPRESSION_LZ4HC = 4,
+	MTBL_COMPRESSION_ZSTD = 5,
 } mtbl_compression_type;
 
+#define MTBL_FILESET_RELOAD_INTERVAL_NEVER	UINT32_MAX /* time interval to never reload filesets */
+
 mtbl_res
 mtbl_compress(
 	mtbl_compression_type,
@@ -48,6 +51,15 @@ mtbl_compress(
 	uint8_t **output,
 	size_t *output_size);
 
+mtbl_res
+mtbl_compress_level(
+	mtbl_compression_type,
+	int compression_level,
+	const uint8_t *input,
+	const size_t input_size,
+	uint8_t **output,
+	size_t *output_size);
+
 mtbl_res
 mtbl_decompress(
 	mtbl_compression_type,
@@ -87,14 +99,28 @@ typedef void
 	const uint8_t *val1, size_t len_val1,
 	uint8_t **merged_val, size_t *len_merged_val);
 
+typedef int
+(*mtbl_dupsort_func)(void *clos,
+	const uint8_t *key, size_t len_key,
+	const uint8_t *val0, size_t len_val0,
+	const uint8_t *val1, size_t len_val1);
+
 typedef void *
 (*mtbl_merge_init_func)(void);
 
 typedef void
 (*mtbl_merge_free_func)(void *clos);
 
+typedef bool
+(*mtbl_filename_filter_func)(const char *fname, void *clos);
+
 /* iter */
 
+typedef mtbl_res
+(*mtbl_iter_seek_func)(
+	void *,
+	const uint8_t *key, size_t len_key);
+
 typedef mtbl_res
 (*mtbl_iter_next_func)(
 	void *,
@@ -104,12 +130,15 @@ typedef mtbl_res
 typedef void
 (*mtbl_iter_free_func)(void *);
 
-struct mtbl_iter *
-mtbl_iter_init(mtbl_iter_next_func, mtbl_iter_free_func, void *clos);
-
 void
 mtbl_iter_destroy(struct mtbl_iter **);
 
+mtbl_res
+mtbl_iter_seek(
+	struct mtbl_iter *,
+	const uint8_t *key, size_t len_key)
+__attribute__((warn_unused_result));
+
 mtbl_res
 mtbl_iter_next(
 	struct mtbl_iter *,
@@ -198,6 +227,11 @@ mtbl_writer_options_set_compression(
 	struct mtbl_writer_options *,
 	mtbl_compression_type);
 
+void
+mtbl_writer_options_set_compression_level(
+	struct mtbl_writer_options *,
+	int);
+
 void
 mtbl_writer_options_set_block_size(
 	struct mtbl_writer_options *,
@@ -241,6 +275,14 @@ mtbl_reader_options_set_verify_checksums(struct mtbl_reader_options *, bool);
 
 /* metadata */
 
+typedef enum {
+	MTBL_FORMAT_V1 = 0,
+	MTBL_FORMAT_V2 = 1
+} mtbl_file_version;
+
+mtbl_file_version
+mtbl_metadata_file_version(const struct mtbl_metadata *);
+
 uint64_t
 mtbl_metadata_index_block_offset(const struct mtbl_metadata *);
 
@@ -296,11 +338,20 @@ mtbl_merger_options_set_merge_func(
 	mtbl_merge_func,
 	void *clos);
 
+void
+mtbl_merger_options_set_dupsort_func(
+	struct mtbl_merger_options *,
+	mtbl_dupsort_func,
+	void *clos);
+
 /* fileset */
 
 struct mtbl_fileset *
 mtbl_fileset_init(const char *fname, const struct mtbl_fileset_options *);
 
+struct mtbl_fileset *
+mtbl_fileset_dup(struct mtbl_fileset *, const struct mtbl_fileset_options *);
+
 void
 mtbl_fileset_destroy(struct mtbl_fileset **);
 
@@ -313,6 +364,13 @@ mtbl_fileset_reload_now(struct mtbl_fileset *);
 const struct mtbl_source *
 mtbl_fileset_source(struct mtbl_fileset *);
 
+void
+mtbl_fileset_partition(struct mtbl_fileset *,
+		mtbl_filename_filter_func,
+		void *,
+		struct mtbl_merger **,
+		struct mtbl_merger **);
+
 /* fileset options */
 
 struct mtbl_fileset_options *
@@ -327,6 +385,19 @@ mtbl_fileset_options_set_merge_func(
 	mtbl_merge_func,
 	void *clos);
 
+void
+mtbl_fileset_options_set_dupsort_func(
+	struct mtbl_fileset_options *,
+	mtbl_dupsort_func,
+	void *clos);
+
+void
+
+mtbl_fileset_options_set_filename_filter_func(
+	struct mtbl_fileset_options *,
+	mtbl_filename_filter_func,
+	void *clos);
+
 void
 mtbl_fileset_options_set_reload_interval(
 	struct mtbl_fileset_options *,
